Crate slice_codec

Crate slice_codec 

TODO write a doc comment explaining this crate.

Modules

buffer
TODO maybe write a comment explaining this module?
decode_from
decoder
encode_into
encoder

Structs

Error
The error type for encoding and decoding functions.

Enums

ErrorKind
A list that specifies all the kinds of errors that can be returned by this crate’s functions. It is typically held by an Error.
InvalidDataErrorKind

Constants

VARINT32_MAX
The largest value that can be represented as a varint32.
VARINT32_MIN
The smallest value that can be represented as a varint32.
VARINT62_MAX
The largest value that can be represented as a varint62.
VARINT62_MIN
The smallest value that can be represented as a varint62.
VARUINT32_MAX
The largest value that can be represented as a varuint32.
VARUINT32_MIN
The smallest value that can be represented as a varuint32.
VARUINT62_MAX
The largest value that can be represented as a varuint62.
VARUINT62_MIN
The smallest value that can be represented as a varuint62.

Type Aliases

Result
A specialized Result type for encoding and decoding functions which may produce errors.