Module buffer

Module buffer 

TODO maybe write a comment explaining this module?

Modules

slice
TODO maybe write a comment explaining this module?
vec
TODO maybe write a comment explaining this module?

Structs

Reservation
Represents a span of bytes that have been reserved in an OutputTarget. See OutputTarget::reserve_space.

Traits

InputSource
A trait for types that can be read from by a Slice decoder.
OutputTarget
A trait for types that can be written to by a Slice encoder.