Decoder

Struct Decoder 

pub struct Decoder<I: InputSource> { /* private fields */ }
TODO

Implementations

Source

impl<I: InputSource> Decoder<I>

pub fn decode_varint<T: TryFrom<i64>>(&mut self) -> Result<T>

Reads between 1 and 8 bytes from the buffer and decodes a single signed integer from them. This integer must of been encoded in the variable length ‘varint’ format.

pub fn decode_varuint<T: TryFrom<u64>>(&mut self) -> Result<T>

Reads between 1 and 8 bytes from the buffer and decodes a single unsigned integer from them. This integer must of been encoded in the variable length ‘varuint’ format.

pub fn decode_size(&mut self) -> Result<usize>

An alias for [decode_varuint] to increase readability.

pub fn skip_tagged_fields(&mut self) -> Result<()>

Skips any remaining tagged fields.

Source

impl<I: InputSource> Decoder<I>

pub fn new(underlying: I) -> Self

TODO

pub fn decode<T: DecodeFrom>(&mut self) -> Result<T>

Attempts to decode a value of the specified type from this decoder’s underlying input-source.