TODO write a doc comment explaining this crate.
Modules
- buffer
- TODO maybe write a comment explaining this module?
- decode_
from - decoder
- encode_
into - encoder
Structs
- Error
- The error type for encoding and decoding functions.
Enums
- Error
Kind - A list that specifies all the kinds of errors that can be returned by this crate’s functions.
It is typically held by an
Error. - Invalid
Data Error Kind
Constants
- VARIN
T32_ MAX - The largest value that can be represented as a
varint32. - VARIN
T32_ MIN - The smallest value that can be represented as a
varint32. - VARIN
T62_ MAX - The largest value that can be represented as a
varint62. - VARIN
T62_ MIN - The smallest value that can be represented as a
varint62. - VARUIN
T32_ MAX - The largest value that can be represented as a
varuint32. - VARUIN
T32_ MIN - The smallest value that can be represented as a
varuint32. - VARUIN
T62_ MAX - The largest value that can be represented as a
varuint62. - VARUIN
T62_ MIN - The smallest value that can be represented as a
varuint62.