TODO maybe write a comment explaining this module?
Modules
- slice
- TODO maybe write a comment explaining this module?
- vec
- TODO maybe write a comment explaining this module?
Structs
- Reservation
- Represents a span of bytes that have been reserved in an
OutputTarget. SeeOutputTarget::reserve_space.
Traits
- Input
Source - A trait for types that can be read from by a Slice decoder.
- Output
Target - A trait for types that can be written to by a Slice encoder.