pub struct Decoder<I: InputSource> { /* private fields */ }Expand description
TODO
Implementations
Sourceimpl<I: InputSource> Decoder<I>
impl<I: InputSource> Decoder<I>
Sourcepub fn decode_varint<T: TryFrom<i64>>(&mut self) -> Result<T>
pub fn decode_varint<T: TryFrom<i64>>(&mut self) -> Result<T>
Reads between 1 and 8 bytes from the buffer and decodes a single signed integer from them. This integer must of been encoded in the variable length ‘varint’ format.
Sourcepub fn decode_varuint<T: TryFrom<u64>>(&mut self) -> Result<T>
pub fn decode_varuint<T: TryFrom<u64>>(&mut self) -> Result<T>
Reads between 1 and 8 bytes from the buffer and decodes a single unsigned integer from them. This integer must of been encoded in the variable length ‘varuint’ format.
Sourcepub fn decode_size(&mut self) -> Result<usize>
pub fn decode_size(&mut self) -> Result<usize>
An alias for [decode_varuint] to increase readability.
Sourcepub fn skip_tagged_fields(&mut self) -> Result<()>
pub fn skip_tagged_fields(&mut self) -> Result<()>
Skips any remaining tagged fields.
Sourceimpl<I: InputSource> Decoder<I>
impl<I: InputSource> Decoder<I>