pub type Result<T> = Result<T, Error>;Expand description
A specialized Result type for encoding and decoding functions which may produce errors.
This typedef is a convenience to avoid repetitively specifying Error as the error type, and is a direct mapping
to a core::result::Result with an Err type of Error.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(Error),
}